=======================================================
replace with the service it implements service overview
=======================================================
The replace with the service it implements service provides...

The replace with the service it implements service consists of the following components:

``ustackdocstheme-api`` service
  Accepts and responds to end user compute API calls...
